@@ -17,7 +17,7 @@ class GetAddressOfIDCUDA(CustomKernel):
     self._use_torch_in_cupy_malloc()
     self.stream = Stream(torch.cuda.current_stream().cuda_stream)
 
-    with open(get_absolute_path("GetAddressOfIDKernel.cu"), "r") as f:
+    with open(get_absolute_path("kernels", "GetAddressOfIDKernel.cu"), "r") as f:
       self.kernel = f.read()
     kernel = (self.kernel
       .replace("_TPB_", str(tpb))
